/*
  Bradley Honeyman
  Oct 8, 2021

  Ref: https://getbootstrap.com/docs/4.0/layout/grid/
 */

import 'package:flutter/material.dart';
import 'package:bootstrap_like_breakpoints/bootstrap_like_breakpoints.dart';
import 'package:bootstrap_like_grid/src/bs_row_state.dart';
import 'package:bootstrap_like_grid/src/bs_column.dart';
import 'package:bootstrap_like_grid/src/wrappers/bs_container_wrapper.dart';

/// Analyzes passed column's breakpoint triggers, and
/// is a column or row based on largest breakpoint passed
class BSRow extends StatefulWidget {
  /// children of the row, can only be BSColumns
  final List<BSColumn> children;

  final MainAxisSize mainAxisSize;
  final MainAxisAlignment mainAxisAlignment;
  final CrossAxisAlignment crossAxisAlignment;
  final Clip clipBehavior;
  final VerticalDirection verticalDirection;
  final TextBaseline? textBaseline;
  final TextDirection? textDirection;

  const BSRow({
    Key? key,
    required this.children,
    this.mainAxisSize = MainAxisSize.max,
    this.mainAxisAlignment = MainAxisAlignment.start,
    this.crossAxisAlignment = CrossAxisAlignment.start,
    this.clipBehavior = Clip.none,
    this.verticalDirection = VerticalDirection.down,
    this.textBaseline,
    this.textDirection,
  }) : super(key: key);

  @override
  State<StatefulWidget> createState() {
    return BSRowState();
  }
}

class BSRowState extends BSRowStateInterface<BSRow> {
  @override
  void initState() {
    super.initState();
  }

  /// returns the width of the largest column
  double _getLargestColumnWidth(List<BSColumn> columns, BuildContext context) {
    double maxWidth = BSContainerWrapper.of(context).width;
    double largest = 0;
    for (int i = 0; i < columns.length; i++) {
      double width = BSBreakPoints.columnWidthFromBreakPointTriggers(
        maxWidth: maxWidth,
        screenWidth: MediaQuery.of(context).size.width,
        breakPointTriggers: columns[i].breakPointTriggers,
      );
      if (width > largest) {
        largest = width;
      }
    }
    return largest;
  }

  /// returns true if the largest passed column is smaller or equal to the width of the
  /// row. Returns false if the largest column is larger, this means the row should be a col
  bool _isRow(BuildContext context, List<BSColumn> columns) {
    double maxWidth = BSContainerWrapper.of(context).width;
    if (_getLargestColumnWidth(columns, context) > maxWidth - 0.1) {
      return false;
    }
    return true;
  }

  @override
  Widget build(BuildContext context) {
    return Flex(
      direction:
          _isRow(context, widget.children) ? Axis.horizontal : Axis.vertical,
      mainAxisSize: widget.mainAxisSize,
      mainAxisAlignment: widget.mainAxisAlignment,
      crossAxisAlignment: widget.crossAxisAlignment,
      clipBehavior: widget.clipBehavior,
      verticalDirection: widget.verticalDirection,
      textBaseline: widget.textBaseline,
      textDirection: widget.textDirection,
      children: widget.children,
    );
  }
}
